core_linked_records_app
=======================

Linked records for the core project.

Quick start
===========

1. Add "core_linked_records_app" to your INSTALLED_APPS setting
---------------------------------------------------------------

.. code:: python

    INSTALLED_APPS = [
      ...
      'core_linked_records_app',
    ]

